@@ -1,25 +1,16 @@
 #!/usr/bin/env python
 """
-Entry point for the ledfx controller. To run this script for development
-purposes use:
+Entry point for LedFx.
+To run this script for development purposes use:
 
-    [console_scripts]
-    python setup.py develop
-    ledfx
-
-For non-development purposes run:
-
-    [console_scripts]
-    python setup.py install
-    ledfx
+    poetry install
+    poetry run ledfx
 
 """
 
 import argparse
-import importlib
 import logging
 import os
-import subprocess
 import sys
 from logging.handlers import RotatingFileHandler
 
@@ -31,21 +22,14 @@ except ImportError:
     have_psutil = False
 
 import ledfx.config as config_helpers
-from ledfx.consts import (
-    PROJECT_VERSION,
-    REQUIRED_PYTHON_STRING,
-    REQUIRED_PYTHON_VERSION,
-)
+from ledfx.consts import PROJECT_VERSION
 from ledfx.core import LedFxCore
-from ledfx.utils import currently_frozen, get_icon_path
-
-
-def validate_python() -> None:
-    """Validate the python version for when manually running"""
-
-    if sys.version_info[:3] < REQUIRED_PYTHON_VERSION:
-        print(("Python {} is required.").format(REQUIRED_PYTHON_STRING))
-        sys.exit(1)
+from ledfx.utils import (
+    check_optional_dependencies,
+    currently_frozen,
+    get_icon_path,
+    log_packages,
+)
 
 
 def reset_logging():
@@ -122,7 +106,7 @@ def parse_args():
     parser.add_argument(
         "--version",
         action="version",
-        version=f"ledfx {PROJECT_VERSION}",
+        version=f"LedFx {PROJECT_VERSION}",
     )
     parser.add_argument(
         "-c",
@@ -206,52 +190,15 @@ def parse_args():
         action="store_true",
         help="This crashes LedFx to test the sentry crash logger",
     )
+    parser.add_argument(
+        "--ci-smoke-test",
+        dest="ci_smoke_test",
+        action="store_true",
+        help="Launch LedFx and then exit after 5 seconds to sanity check the install",
+    )
     return parser.parse_args()
 
 
-def installed_via_pip():
-    """Check to see if LedFx is installed via pip
-    Returns:
-        boolean
-    """
-    pip_spec = importlib.util.find_spec("pip")
-    if pip_spec is None:
-        return False
-    pip_package_command = subprocess.check_output(
-        [sys.executable, "-m", "pip", "freeze"]
-    )
-    installed_packages = [
-        r.decode().split("==")[0] for r in pip_package_command.split()
-    ]
-    if "ledfx" in installed_packages:
-        return True
-    else:
-        return False
-
-
-def log_packages():
-    from platform import (
-        processor,
-        python_build,
-        python_implementation,
-        python_version,
-        release,
-        system,
-    )
-
-    from pkg_resources import working_set
-
-    _LOGGER.debug(f"{system()} : {release()} : {processor()}")
-    _LOGGER.debug(
-        f"{python_version()} : {python_build()} : {python_implementation()}"
-    )
-    _LOGGER.debug("Packages")
-    dists = [d for d in working_set]
-    dists.sort(key=lambda x: x.project_name)
-    for dist in dists:
-        _LOGGER.debug(f"{dist.project_name} : {dist.version}")
-
-
 def main():
     """Main entry point allowing external calls"""
     args = parse_args()
@@ -259,6 +206,9 @@ def main():
     setup_logging(args.loglevel, config_dir=args.config)
     config_helpers.load_logger()
 
+    if _LOGGER.isEnabledFor(logging.DEBUG):
+        log_packages()
+    check_optional_dependencies()
     # Set some process priority optimisations
     if have_psutil:
         p = psutil.Process(os.getpid())
@@ -297,7 +247,6 @@ def main():
         except Exception as Error:
             msg = f"Error: Unable to virtual tray icon. Shutting down. Error: {Error}"
             _LOGGER.critical(msg)
-            raise Exception(msg)
             sys.exit(0)
 
         from PIL import Image
@@ -310,9 +259,6 @@ def main():
     else:
         icon = None
 
-    if _LOGGER.isEnabledFor(logging.DEBUG):
-        log_packages()
-
     if icon:
         icon.run(setup=entry_point)
     else:
@@ -336,6 +282,7 @@ def entry_point(icon=None):
             port=args.port,
             port_s=args.port_s,
             icon=icon,
+            ci_testing=args.ci_smoke_test,
         )
 
         exit_code = ledfx.start(open_ui=args.open_ui)
