@@ -16,55 +16,56 @@ class DeviceEndpoint(RestEndpoint):
     ENDPOINT_PATH = "/api/devices/{device_id}"
 
     async def get(self, device_id) -> web.Response:
+        """
+        Get the configuration of a device.
+
+        Args:
+            device_id (str): The ID of the device.
+
+        Returns:
+            web.Response: The response containing the device configuration.
+        """
         device = self._ledfx.devices.get(device_id)
         if device is None:
-            response = {"not found": 404}
-            return web.json_response(data=response, status=404)
+            return await self.invalid_request("{device} was not found")
 
         response = device.config
-        return web.json_response(data=response, status=200)
+        return await self.bare_request_success(response)
 
     async def put(self, device_id, request) -> web.Response:
+        """
+        Update the configuration of a device.
+
+        Args:
+            device_id (str): The ID of the device.
+            request (web.Request): The request object containing device `config`.
+
+        Returns:
+            web.Response: The response indicating the success or failure of the update.
+        """
         device = self._ledfx.devices.get(device_id)
         if device is None:
-            response = {"not found": 404}
-            return web.json_response(data=response, status=404)
+            return await self.invalid_request(f"{device} was not found")
 
         try:
             data = await request.json()
         except JSONDecodeError:
-            response = {
-                "status": "failed",
-                "reason": "JSON Decoding failed",
-            }
-            return web.json_response(data=response, status=400)
+            return await self.json_decode_error()
         device_config = data.get("config")
         if device_config is None:
-            response = {
-                "status": "failed",
-                "reason": 'Required attribute "config" was not provided',
-            }
-            return web.json_response(data=response, status=400)
-
-        _LOGGER.debug(
-            ("Updating device {} with config {}").format(
-                device_id, device_config
+            return await self.invalid_request(
+                "Required attribute 'config' was not provided"
             )
+        _LOGGER.debug(
+            f"Updating device {device_id} with config {device_config}"
         )
 
         try:
             device.update_config(device_config)
-            response = {"status": "success"}
-            status = 200
         except (voluptuous.Error, ValueError) as msg:
-            response = {
-                "status": "failed",
-                "payload": {"type": "warning", "reason": str(msg)},
-            }
-            status = 202
-            # If there's an error updating config, don't write that config, just return an error
-            return web.json_response(data=response, status=status)
-
+            error_message = f"Error updating device {device_id}: {msg}"
+            _LOGGER.warning(error_message)
+            return await self.internal_error("error", error_message)
         # Update and save the configuration
         for device in self._ledfx.config["devices"]:
             if device["id"] == device_id:
@@ -74,19 +75,30 @@ class DeviceEndpoint(RestEndpoint):
             config=self._ledfx.config,
             config_dir=self._ledfx.config_dir,
         )
-
-        return web.json_response(data=response, status=status)
+        return await self.request_success()
 
     async def post(self, device_id, request) -> web.Response:
+        """
+        Handle POST request for a device.
+
+        Args:
+            device_id (str): The ID of the device.
+            request (web.Request): The request object. Not currently used.
+
+        Returns:
+            web.Response: The response object.
+        """
+        if device_id is None:
+            return await self.invalid_request("No `device_id` provided")
         device = self._ledfx.devices.get(device_id)
         if device is None:
-            response = {"not found": 404}
-            return web.json_response(data=response, status=404)
+            error_message = f"Device with ID {device_id} not found"
+            _LOGGER.info(error_message)
+            return await self.invalid_request(error_message)
 
         try:
             if device.type == "wled":
                 await device.resolve_address()
-            status = 200
 
             response = {"status": "success", "virtuals": {}}
             response["paused"] = self._ledfx.virtuals._paused
@@ -111,22 +123,30 @@ class DeviceEndpoint(RestEndpoint):
                     ] = effect_response
 
         except (voluptuous.Error, ValueError) as msg:
-            response = {
-                "status": "failed",
-                "payload": {"type": "warning", "reason": str(msg)},
-            }
-            status = 202
-            # If there's an error updating config, don't write that config, just return an error
-            return web.json_response(data=response, status=status)
+            error_message = f"Error creating device {device_id}: {msg}"
+            _LOGGER.warning(error_message)
+            return await self.internal_error("error", error_message)
 
         device.activate()
-        return web.json_response(data=response, status=status)
+        return await self.bare_request_success(response)
 
     async def delete(self, device_id) -> web.Response:
+        """
+        Deletes a device with the specified device_id.
+
+        Args:
+            device_id (str): The ID of the device to be deleted.
+
+        Returns:
+            web.Response: The response indicating the success or failure of the delete operation.
+        """
+        if device_id is None:
+            return await self.invalid_request("No device ID provided")
         device = self._ledfx.devices.get(device_id)
         if device is None:
-            response = {"not found": 404}
-            return web.json_response(data=response, status=404)
+            error_message = f"Device with ID {device_id} not found"
+            _LOGGER.info(error_message)
+            return await self.invalid_request(error_message)
 
         device.clear_effect()
         await device.remove_from_virtuals()
@@ -142,6 +162,4 @@ class DeviceEndpoint(RestEndpoint):
             config=self._ledfx.config,
             config_dir=self._ledfx.config_dir,
         )
-
-        response = {"status": "success"}
-        return web.json_response(data=response, status=200)
+        return await self.request_success()
