@@ -29,6 +29,7 @@ from ledfx.events import (
 )
 from ledfx.http_manager import HttpServer
 from ledfx.integrations import Integrations
+from ledfx.mdns_manager import ZeroConfRunner
 from ledfx.presets import ledfx_presets
 from ledfx.scenes import Scenes
 from ledfx.utils import (
@@ -52,6 +53,7 @@ class LedFxCore:
         port=None,
         port_s=None,
         icon=None,
+        ci_testing=False,
     ):
         self.icon = icon
         self.config_dir = config_dir
@@ -60,6 +62,7 @@ class LedFxCore:
         self.host = host if host else self.config["host"]
         self.port = port if port else self.config["port"]
         self.port_s = port_s if port_s else self.config["port_s"]
+        self.ci_testing = ci_testing
 
         if sys.platform == "win32":
             self.loop = asyncio.ProactorEventLoop()
@@ -202,17 +205,6 @@ class LedFxCore:
     def start(self, open_ui=False):
         async_fire_and_forget(self.async_start(open_ui=open_ui), self.loop)
 
-        # Windows does not seem to handle Ctrl+C well so as a workaround
-        # register a handler and manually stop the app
-        if sys.platform == "win32":
-            import win32api
-
-            def handle_win32_interrupt(sig, func=None):
-                self.stop(exit_code=2)
-                return True
-
-            win32api.SetConsoleCtrlHandler(handle_win32_interrupt, 1)
-
         try:
             self.loop.run_forever()
         except KeyboardInterrupt:
@@ -268,17 +260,14 @@ class LedFxCore:
         self.devices.create_from_config(self.config["devices"])
         await self.devices.async_initialize_devices()
 
-        # sync_mode = WLED_CONFIG_SCHEMA(self.config["wled_preferences"])[
-        #     "wled_preferred_mode"
-        # ]
-        # if sync_mode:
-        #     await self.devices.set_wleds_sync_mode(sync_mode)
-
+        self.zeroconf = ZeroConfRunner(ledfx=self)
         self.virtuals.create_from_config(self.config["virtuals"])
         self.integrations.create_from_config(self.config["integrations"])
 
         if self.config["scan_on_startup"]:
-            async_fire_and_forget(self.devices.find_wled_devices(), self.loop)
+            async_fire_and_forget(
+                self.zeroconf.discover_wled_devices(), self.loop
+            )
 
         async_fire_and_forget(
             self.integrations.activate_integrations(), self.loop
@@ -287,6 +276,9 @@ class LedFxCore:
         if open_ui:
             self.open_ui()
 
+        if self.ci_testing:
+            await asyncio.sleep(5)
+            self.stop(5)
         await self.flush_loop()
 
     def stop(self, exit_code):
@@ -311,11 +303,11 @@ class LedFxCore:
             _LOGGER.info("LedFx Shutdown Request via API. Shutting Down.")
         if exit_code == 4:
             _LOGGER.info("LedFx is restarting.")
-
+        if exit_code == 5:
+            _LOGGER.info("LedFx Shutdown via CI Testing Flag.")
         # Fire a shutdown event and flush the loop
         self.events.fire_event(LedFxShutdownEvent())
         await asyncio.sleep(0)
-
         _LOGGER.info("Stopping HttpServer...")
         await self.http.stop()
 
